from hypothesis_jsonschema import from_schema
from thd_json.projection import get_projection_validator
from thd_json.header import get_header_validator
from thd_json.source import get_source_validator
from thd_json.detector import get_detector_validator
from thd_json.image import get_image_validator
from thd_json.roi import get_roi_validator
from thd_json.volume import get_volume_validator
from hypothesis import given, settings
import json
from pathlib import Path


SAVE_FOLDER = Path("./examples/generated")


def main():
    for name, get_validator in [
        ("projection", get_projection_validator),
        ("header", get_header_validator),
        ("source", get_source_validator),
        ("detector", get_detector_validator),
        ("image", get_image_validator),
        ("roi", get_roi_validator),
        ("volume", get_volume_validator),
    ]:
        validator = get_validator()
        schema = validator.get_schema()
        strategy = from_schema(schema)

        @settings(max_examples=1)
        @given(strategy)
        def schema(data):
            with open(SAVE_FOLDER / f"example_{name}.json", "w") as f:
                json.dump(data, f, indent=4)
            return

        schema()


if __name__ == "__main__":
    main()
